==> haskell-bz2-1.0.1.1-104.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bz2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bz2
version:              1.0.1.1
visibility:           public
id:                   bz2-1.0.1.1-IehciT49pDzB3Nt7Ij61pt
key:                  bz2-1.0.1.1-IehciT49pDzB3Nt7Ij61pt
license:              BSD-3-Clause
copyright:            Copyright: (c) 2020 Vanessa McHale
maintainer:           vamchale@gmail.com
author:               Vanessa McHale
synopsis:             Bindings to libbz2
description:          High-level bindings to libbz2 via ByteString
category:             Compression
abi:                  c6aac1996d33300506d0cd0b39dc6a20
exposed:              True
exposed-modules:      Codec.Compression.BZip
hidden-modules:
    Codec.Compression.BZip.Common Codec.Compression.BZip.Foreign.Common
    Codec.Compression.BZip.Foreign.Compress
    Codec.Compression.BZip.Foreign.Decompress
    Codec.Compression.BZip.Unpack Codec.Compression.BZip.Pack

import-dirs:          /usr/lib/ghc-9.6.6/site-local/bz2-1.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bz2-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bz2-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bz2
hs-libraries:         HSbz2-1.0.1.1-IehciT49pDzB3Nt7Ij61pt
extra-libraries:      bz2
depends:              base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-bz2/html/bz2.haddock
haddock-html:         /usr/share/doc/haskell-bz2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bz2-1.0.1.1-105-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bz2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bz2
version:              1.0.1.1
visibility:           public
id:                   bz2-1.0.1.1-1QJE1GiiD5uGbFaD3CqM6G
key:                  bz2-1.0.1.1-1QJE1GiiD5uGbFaD3CqM6G
license:              BSD-3-Clause
copyright:            Copyright: (c) 2020 Vanessa McHale
maintainer:           vamchale@gmail.com
author:               Vanessa McHale
synopsis:             Bindings to libbz2
description:          High-level bindings to libbz2 via ByteString
category:             Compression
abi:                  47b03f02ea18f14941005624cd7fdde2
exposed:              True
exposed-modules:      Codec.Compression.BZip
hidden-modules:
    Codec.Compression.BZip.Common Codec.Compression.BZip.Foreign.Common
    Codec.Compression.BZip.Foreign.Compress
    Codec.Compression.BZip.Foreign.Decompress
    Codec.Compression.BZip.Unpack Codec.Compression.BZip.Pack

import-dirs:          /usr/lib/ghc-9.6.6/site-local/bz2-1.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bz2-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bz2-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bz2
hs-libraries:         HSbz2-1.0.1.1-1QJE1GiiD5uGbFaD3CqM6G
extra-libraries:      bz2
depends:              base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-bz2/html/bz2.haddock
haddock-html:         /usr/share/doc/haskell-bz2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
